| Title: | "chores" extension ggplot2 LLM assistant |
|---|---|
| Description: | Extension of "chores" FKA "pals", a LLM assistant add-in for RStudio and Positron IDEs built on "ellmer". "ggpal2" is an assistant designed to help with ggplot2. |
| Authors: | Frank Hull [aut, cre] |
| Maintainer: | Frank Hull <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1.9000 |
| Built: | 2026-05-21 10:19:07 UTC |
| Source: | https://github.com/frankiethull/ggpal2 |
how-to use "ggplot2", the ggplot2-replace pal,
Pals are interfaced with the via the pal addin. For easiest access, we recommend registering the pal addin to a keyboard shortcut.
i.e. for RStudio IDE, Tools > Modify Keyboard Shortcuts > Search "Pal"
we suggest Ctrl+Alt+P (or Ctrl+Cmd+P on macOS).
for more information, follow the "chores" instructions at https://simonpcouch.github.io/chores/articles/custom.html
"chores" https://simonpcouch.github.io/chores/index.html